@@ -62,6 +62,7 @@ import shutil
 import struct
 import asyncio
 import logging
+import binascii
 import ipaddress
 import contextlib
 import collections
@@ -595,6 +596,11 @@ class StorTypeFqdn(StorTypeUtf8):
             self._getIndxByts(norm[::-1]),
         )
 
+    def decodeIndx(self, bytz):
+        if len(bytz) >= 256:
+            return s_common.novalu
+        return bytz.decode('utf8', 'surrogatepass')[::-1]
+
     def __init__(self, layr):
         StorType.__init__(self, layr, STOR_TYPE_UTF8)
         self.lifters.update({
@@ -921,8 +927,14 @@ class StorTypeGuid(StorType):
         StorType.__init__(self, layr, STOR_TYPE_GUID)
         self.lifters.update({
             '=': self._liftGuidEq,
+            '^=': self._liftGuidPref,
         })
 
+    async def _liftGuidPref(self, liftby, byts):
+        # valu is already bytes of the guid prefix
+        for item in liftby.keyBuidsByPref(byts):
+            yield item
+
     async def _liftGuidEq(self, liftby, valu):
         indx = s_common.uhex(valu)
         for item in liftby.keyBuidsByDups(indx):
@@ -1324,7 +1336,7 @@ class Layer(s_nexus.Pusher):
 
         logger.warning(f'...complete! ({count} nodes)')
 
-    async def _layrV3toV4(self):
+    async def _layrV3toV5(self):
 
         sode = collections.defaultdict(dict)
 
@@ -1351,24 +1363,52 @@ class Layer(s_nexus.Pusher):
             indxbyts = lkey[8:]
             valu, stortype = pval
             realtype = stortype & 0x7fff
+            realstor = self.stortypes[realtype]
 
-            if realtype == STOR_TYPE_MSGP:
-                for aval in valu:
-                    if s_common.buid(aval) == indxbyts:
-                        break
-                else:
-                    self.layrslab.delete(lkey, lval, db=self.byarray)
-                    sode.clear()
-                    continue
+            for aval in valu:
+                if indxbyts in realstor.indx(aval):
+                    break
             else:
-                indxvalu = self.stortypes[realtype].decodeIndx(indxbyts)
-                if indxvalu not in valu:
-                    self.layrslab.delete(lkey, lval, db=self.byarray)
+                self.layrslab.delete(lkey, lval, db=self.byarray)
 
             sode.clear()
 
-        self.meta.set('version', 4)
-        self.layrvers = 4
+        self.meta.set('version', 5)
+        self.layrvers = 5
+
+        logger.warning(f'...complete!')
+
+    async def _layrV4toV5(self):
+
+        sode = collections.defaultdict(dict)
+
+        logger.warning(f'Rebuilding layer byarray index: {self.dirn}')
+
+        for byts, abrv in self.propabrv.slab.scanByFull(db=self.propabrv.name2abrv):
+
+            form, prop = s_msgpack.un(byts)
+            if form is None or prop is None:
+                continue
+
+            for lkey, buid in self.layrslab.scanByPref(abrv, db=self.byprop):
+                byts = self.layrslab.get(buid, db=self.bybuidv3)
+                if byts is not None:
+                    sode.clear()
+                    sode.update(s_msgpack.un(byts))
+
+                pval = sode['props'].get(prop)
+                if pval is None:
+                    continue
+
+                valu, stortype = pval
+                if not stortype & STOR_FLAG_ARRAY:
+                    break
+
+                for indx in self.getStorIndx(stortype, valu):
+                    self.layrslab.put(abrv + indx, buid, db=self.byarray)
+
+        self.meta.set('version', 5)
+        self.layrvers = 5
 
         logger.warning(f'...complete!')
 
@@ -1393,7 +1433,7 @@ class Layer(s_nexus.Pusher):
         metadb = self.layrslab.initdb('layer:meta')
         self.meta = s_lmdbslab.SlabDict(self.layrslab, db=metadb)
         if self.fresh:
-            self.meta.set('version', 4)
+            self.meta.set('version', 5)
 
         self.formcounts = await self.layrslab.getHotCount('count:forms')
 
@@ -1434,7 +1474,10 @@ class Layer(s_nexus.Pusher):
             await self._layrV2toV3()
 
         if self.layrvers < 4:
-            await self._layrV3toV4()
+            await self._layrV3toV5()
+
+        if self.layrvers < 5:
+            await self._layrV4toV5()
 
     async def getLayerSize(self):
         '''
@@ -1449,7 +1492,7 @@ class Layer(s_nexus.Pusher):
                 except OSError:  # pragma: no cover
                     pass
                 else:
-                    totalsize += stat.st_size
+                    totalsize += stat.st_blocks * 512
         return totalsize
 
     @s_nexus.Pusher.onPushAuto('layer:set')
@@ -1483,14 +1526,14 @@ class Layer(s_nexus.Pusher):
     async def getFormCounts(self):
         return self.formcounts.pack()
 
-    @s_cache.memoize()
+    @s_cache.memoizemethod()
     def getPropAbrv(self, form, prop):
         return self.propabrv.bytsToAbrv(s_msgpack.en((form, prop)))
 
     def setPropAbrv(self, form, prop):
         return self.propabrv.setBytsToAbrv(s_msgpack.en((form, prop)))
 
-    @s_cache.memoize()
+    @s_cache.memoizemethod()
     def getTagPropAbrv(self, *args):
         return self.tagpropabrv.bytsToAbrv(s_msgpack.en(args))
 
