@@ -8,6 +8,79 @@ import synapse.lib.version as s_version
 
 logger = logging.getLogger(__name__)
 
+class Cpe23Str(s_types.Str):
+    '''
+    CPE 2.3 Formatted String
+
+    https://nvlpubs.nist.gov/nistpubs/Legacy/IR/nistir7695.pdf
+
+    (Section 6.2)
+
+    cpe:2.3: part : vendor : product : version : update : edition :
+        language : sw_edition : target_sw : target_hw : other
+
+    * = "any"
+    - = N/A
+    '''
+    def __init__(self, modl, name, info, opts):
+        opts['lower'] = True
+        s_types.Str.__init__(self, modl, name, info, opts)
+
+    def _splitCpe23(self, text):
+
+        part = ''
+        parts = []
+
+        genr = iter(text)
+        try:
+            while True:
+
+                c = next(genr)
+
+                if c == '\\':
+                    c += next(genr)
+
+                if c == ':':
+                    parts.append(part)
+                    part = ''
+                    continue
+
+                part += c
+
+        except StopIteration:
+            parts.append(part)
+
+        return parts
+
+    def _normPyStr(self, valu):
+
+        if not valu.startswith('cpe:2.3:'):
+            mesg = 'CPE 2.3 string is expected to start with "cpe:2.3:"'
+            raise s_exc.BadTypeValu(valu=valu, mesg=mesg)
+
+        text, info = s_types.Str._normPyStr(self, valu)
+        parts = self._splitCpe23(text)
+
+        if len(parts) != 13:
+            mesg = f'CPE 2.3 string has {len(parts)} parts, expected 13.'
+            raise s_exc.BadTypeValu(valu=valu, mesg=mesg)
+
+        subs = {
+            'part': parts[2],
+            'vendor': parts[3],
+            'product': parts[4],
+            'version': parts[5],
+            'update': parts[6],
+            'edition': parts[7],
+            'language': parts[8],
+            'sw_edition': parts[9],
+            'target_sw': parts[10],
+            'target_hw': parts[11],
+            'other': parts[12],
+        }
+
+        return ':'.join(parts), {'subs': subs}
+
 class SemVer(s_types.Int):
     '''
     Provides support for parsing a semantic version string into its component
@@ -152,6 +225,9 @@ class ItModule(s_module.CoreModule):
                 ('it:semver', 'synapse.models.infotech.SemVer', {}, {
                     'doc': 'Semantic Version type.',
                 }),
+                ('it:sec:cpe', 'synapse.models.infotech.Cpe23Str', {}, {
+                    'doc': 'A NIST CPE 2.3 Formatted String',
+                }),
             ),
             'types': (
                 ('it:hostname', ('str', {'strip': True, 'lower': True}), {
@@ -160,6 +236,21 @@ class ItModule(s_module.CoreModule):
                 ('it:host', ('guid', {}), {
                     'doc': 'A GUID that represents a host or system.'
                 }),
+                ('it:network', ('guid', {}), {
+                    'doc': 'A GUID that represents a logical network.'
+                }),
+                ('it:domain', ('guid', {}), {
+                    'doc': 'A logical boundary of authentication and configuration such as a windows domain.'
+                }),
+                ('it:account', ('guid', {}), {
+                    'doc': 'A GUID that represents an account on a host or network.'
+                }),
+                ('it:group', ('guid', {}), {
+                    'doc': 'A GUID that represents a group on a host or network.'
+                }),
+                ('it:logon', ('guid', {}), {
+                    'doc': 'A GUID that represents an individual logon/logoff event.'
+                }),
                 ('it:hosturl', ('comp', {'fields': (('host', 'it:host'), ('url', 'inet:url'))}), {
                     'doc': 'A url hosted on or served by a host or system.',
                 }),
@@ -168,6 +259,30 @@ class ItModule(s_module.CoreModule):
                     'doc': 'A vulnerability as designated by a Common Vulnerabilities and Exposures (CVE) number.',
                     'ex': 'cve-2012-0158'
                 }),
+                ('it:sec:cwe', ('str', {'regex': r'^CWE-[0-9]{1,8}$'}), {
+                    'doc': 'NIST NVD Common Weaknesses Enumeration Specification',
+                    'ex': 'CWE-120',
+                }),
+                ('it:mitre:attack:group', ('str', {'regex': r'^G[0-9]{4}$'}), {
+                    'doc': 'A Mitre ATT&CK Group ID.',
+                    'ex': 'G0100',
+                }),
+                ('it:mitre:attack:tactic', ('str', {'regex': r'^TA[0-9]{4}$'}), {
+                    'doc': 'A Mitre ATT&CK Tactic ID.',
+                    'ex': 'TA0040',
+                }),
+                ('it:mitre:attack:technique', ('str', {'regex': r'^T[0-9]{4}(.[0-9]{3})?$'}), {
+                    'doc': 'A Mitre ATT&CK Technique ID.',
+                    'ex': 'T1548',
+                }),
+                ('it:mitre:attack:mitigation', ('str', {'regex': r'^M[0-9]{4}$'}), {
+                    'doc': 'A Mitre ATT&CK Mitigation ID.',
+                    'ex': 'M1036',
+                }),
+                ('it:mitre:attack:software', ('str', {'regex': r'^S[0-9]{4}$'}), {
+                    'doc': 'A Mitre ATT&CK Software ID.',
+                    'ex': 'S0154',
+                }),
                 ('it:dev:str', ('str', {}), {
                     'doc': 'A developer-selected string.'
                 }),
@@ -194,6 +309,11 @@ class ItModule(s_module.CoreModule):
                 ('it:adid', ('str', {'lower': True, 'strip': True}), {
                     'doc': 'An advertising identification string.'}),
 
+                ('it:os:windows:sid', ('str', {'regex': r'^S-1-[0-59]-\d{2}-\d{8,10}-\d{8,10}-\d{8,10}-[1-9]\d{3}$'}), {
+                    'doc': 'A Microsoft Windows Security Identifier.',
+                    'ex': 'S-1-5-21-1220945662-1202665555-839525555-5555',
+                }),
+
                 ('it:os:ios:idfa', ('it:adid', {}), {
                     'doc': 'An iOS advertising identification string.'}),
 
@@ -317,6 +437,22 @@ class ItModule(s_module.CoreModule):
                     'doc': 'A function from an imported library.',
                 }),
             ),
+
+            'interfaces': (
+                ('it:host:activity', {
+                    'props': (
+                        ('exe', ('file:bytes', {}), {
+                            'doc': 'The executable file which caused the activity.'}),
+                        ('proc', ('it:exec:proc', {}), {
+                            'doc': 'The host process which caused the activity.'}),
+                        ('host', ('it:host', {}), {
+                            'doc': 'The host on which the activity occurred.'}),
+                        ('time', ('time', {}), {
+                            'doc': 'The time that the activity started.'}),
+                    ),
+                }),
+            ),
+
             'forms': (
                 ('it:hostname', {}, ()),
 
@@ -327,6 +463,9 @@ class ItModule(s_module.CoreModule):
                     ('desc', ('str', {}), {
                         'doc': 'A free-form description of the host.',
                     }),
+                    ('domain', ('it:domain', {}), {
+                        'doc': 'The authentication domain that the host is a member of.',
+                    }),
                     ('ipv4', ('inet:ipv4', {}), {
                         'doc': 'The last known ipv4 address for the host.'
                     }),
@@ -358,6 +497,129 @@ class ItModule(s_module.CoreModule):
                         'doc': 'The org that operates the given host.',
                     }),
                 )),
+                ('it:domain', {}, (
+                    ('name', ('str', {'lower': True, 'strip': True, 'onespace': True}), {
+                        'doc': 'The name of the domain.',
+                    }),
+                    ('desc', ('str', {}), {
+                        'doc': 'A brief description of the domain.',
+                    }),
+                    ('org', ('ou:org', {}), {
+                        'doc': 'The org that operates the given domain.',
+                    }),
+                )),
+                ('it:network', {}, (
+                    ('name', ('str', {'lower': True, 'strip': True, 'onespace': True}), {
+                        'doc': 'The name of the network.',
+                    }),
+                    ('desc', ('str', {}), {
+                        'doc': 'A brief description of the network.',
+                    }),
+                    ('org', ('ou:org', {}), {
+                        'doc': 'The org that owns/operates the network.',
+                    }),
+                    ('net4', ('inet:net4', {}), {
+                        'doc': 'The optional contiguous IPv4 address range of this network.',
+                    }),
+                    ('net6', ('inet:net6', {}), {
+                        'doc': 'The optional contiguous IPv6 address range of this network.',
+                    }),
+                )),
+                ('it:account', {}, (
+                    ('user', ('inet:user', {}), {
+                        'doc': 'The username associated with the account',
+                    }),
+                    ('contact', ('ps:contact', {}), {
+                        'doc': 'Additional contact information associated with this account.',
+                    }),
+                    ('host', ('it:host', {}), {
+                        'doc': 'The host where the account is registered.',
+                    }),
+                    ('domain', ('it:domain', {}), {
+                        'doc': 'The authentication domain where the account is registered.',
+                    }),
+                    ('posix:uid', ('int', {}), {
+                        'doc': 'The user ID of the account.',
+                        'ex': '1001',
+                    }),
+                    ('posix:gid', ('int', {}), {
+                        'doc': 'The primary group ID of the account.',
+                        'ex': '1001',
+                    }),
+                    ('posix:gecos', ('int', {}), {
+                        'doc': 'The GECOS field for the POSIX account.',
+                    }),
+                    ('posix:home', ('file:path', {}), {
+                        'doc': "The path to the POSIX account's home directory.",
+                        'ex': '/home/visi',
+                    }),
+                    ('posix:shell', ('file:path', {}), {
+                        'doc': "The path to the POSIX account's default shell.",
+                        'ex': '/bin/bash',
+                    }),
+                    ('windows:sid', ('it:os:windows:sid', {}), {
+                        'doc': 'The Microsoft Windows Security Identifier of the account.',
+                    }),
+                    ('groups', ('array', {'type': 'it:group'}), {
+                        'doc': 'An array of groups that the account is a member of.',
+                    }),
+                )),
+                ('it:group', {}, (
+                    ('name', ('str', {'lower': True, 'strip': True, 'onespace': True}), {
+                        'doc': 'The name of the group.',
+                    }),
+                    ('desc', ('str', {}), {
+                        'doc': 'A brief description of the group.',
+                    }),
+                    ('host', ('it:host', {}), {
+                        'doc': 'The host where the group is registered.',
+                    }),
+                    ('domain', ('it:domain', {}), {
+                        'doc': 'The authentication domain where the group is registered.',
+                    }),
+                    ('groups', ('array', {'type': 'it:group'}), {
+                        'doc': 'Groups that are a member of this group.',
+                    }),
+                    ('posix:gid', ('int', {}), {
+                        'doc': 'The primary group ID of the account.',
+                        'ex': '1001',
+                    }),
+                    ('windows:sid', ('it:os:windows:sid', {}), {
+                        'doc': 'The Microsoft Windows Security Identifier of the group.',
+                    }),
+                )),
+                ('it:logon', {}, (
+                    ('time', ('time', {}), {
+                        'doc': 'The time the logon occured.',
+                    }),
+                    ('success', ('bool', {}), {
+                        'doc': 'Set to false to indicate an unsuccessful logon attempt.',
+                    }),
+                    ('logoff:time', ('time', {}), {
+                        'doc': 'The time the logon session ended.',
+                    }),
+                    ('host', ('it:host', {}), {
+                        'doc': 'The host that the account logged in to.',
+                    }),
+                    ('account', ('it:account', {}), {
+                        'doc': 'The account that logged in.',
+                    }),
+                    ('creds', ('auth:creds', {}), {
+                        'doc': 'The credentials that were used for the logon.',
+                    }),
+                    ('duration', ('duration', {}), {
+                        'doc': 'The duration of the logon session.',
+                    }),
+                    ('client:host', ('it:host', {}), {
+                        'doc': 'The host where the logon originated.',
+                    }),
+                    ('client:ipv4', ('inet:ipv4', {}), {
+                        'doc': 'The IPv4 where the logon originated.',
+                    }),
+                    ('client:ipv6', ('inet:ipv6', {}), {
+                        'doc': 'The IPv6 where the logon originated.',
+                    }),
+                )),
                 ('it:hosturl', {}, (
                     ('host', ('it:host', {}), {
                         'ro': True,
@@ -378,6 +640,192 @@ class ItModule(s_module.CoreModule):
                         'doc': 'A free-form description of the CVE vulnerability.',
                         'disp': {'hint': 'text'},
                     }),
+                    ('url', ('inet:url', {}), {
+                        'doc': 'A URL linking this CVE to a full description.',
+                    }),
+                    ('references', ('array', {'type': 'inet:url', 'uniq': True}), {
+                        'doc': 'An array of URLs that document the CVE ID.',
+                    }),
+                )),
+                ('it:sec:cpe', {}, (
+                    ('part', ('str', {'lower': True, 'strip': True}), {
+                        'ro': True,
+                        'doc': 'The "part" field from the CPE 2.3 string.'}),
+                    ('vendor', ('ou:name', {}), {
+                        'ro': True,
+                        'doc': 'The "vendor" field from the CPE 2.3 string.'}),
+                    ('product', ('str', {'lower': True, 'strip': True}), {
+                        'ro': True,
+                        'doc': 'The "product" field from the CPE 2.3 string.'}),
+                    ('version', ('str', {'lower': True, 'strip': True}), {
+                        'ro': True,
+                        'doc': 'The "version" field from the CPE 2.3 string.'}),
+                    ('update', ('str', {'lower': True, 'strip': True}), {
+                        'ro': True,
+                        'doc': 'The "update" field from the CPE 2.3 string.'}),
+                    ('edition', ('str', {'lower': True, 'strip': True}), {
+                        'ro': True,
+                        'doc': 'The "edition" field from the CPE 2.3 string.'}),
+                    ('language', ('str', {'lower': True, 'strip': True}), {
+                        'ro': True,
+                        'doc': 'The "language" field from the CPE 2.3 string.'}),
+                    ('sw_edition', ('str', {'lower': True, 'strip': True}), {
+                        'ro': True,
+                        'doc': 'The "sw_edition" field from the CPE 2.3 string.'}),
+                    ('target_sw', ('str', {'lower': True, 'strip': True}), {
+                        'ro': True,
+                        'doc': 'The "target_sw" field from the CPE 2.3 string.'}),
+                    ('target_hw', ('str', {'lower': True, 'strip': True}), {
+                        'ro': True,
+                        'doc': 'The "target_hw" field from the CPE 2.3 string.'}),
+                    ('other', ('str', {'lower': True, 'strip': True}), {
+                        'ro': True,
+                        'doc': 'The "other" field from the CPE 2.3 string.'}),
+                )),
+                ('it:sec:cwe', {}, (
+                    ('name', ('str', {}), {
+                        'doc': 'The CWE description field.',
+                        'ex': 'Buffer Copy without Checking Size of Input (Classic Buffer Overflow)',
+                    }),
+                    ('desc', ('str', {}), {
+                        'doc': 'The CWE description field.',
+                        'disp': {'hint': 'text'},
+                    }),
+                    ('url', ('inet:url', {}), {
+                        'doc': 'A URL linking this CWE to a full description.',
+                    }),
+                    ('parents', ('array', {'type': 'it:sec:cwe',
+                                           'uniq': True, 'sorted': True, 'split': ','}), {
+                        'doc': 'An array of ChildOf CWE Relationships.'
+                    }),
+                )),
+                ('it:mitre:attack:group', {}, (
+                    ('org', ('ou:org', {}), {
+                        'doc': 'Used to map an ATT&CK group to a synapse ou:org.',
+                    }),
+                    ('name', ('ou:name', {}), {
+                        'doc': 'The primary name for the ATT&CK group.',
+                    }),
+                    ('names', ('array', {'type': 'ou:name', 'uniq': True, 'sorted': True}), {
+                        'doc': 'An array of alternate names for the ATT&CK group.',
+                    }),
+                    ('desc', ('str', {}), {
+                        'doc': 'A description of the ATT&CK group.',
+                        'disp': {'hint': 'text'},
+                    }),
+                    ('url', ('inet:url', {}), {
+                        'doc': 'The URL that documents the ATT&CK group.',
+                    }),
+                    ('tag', ('syn:tag', {}), {
+                        'doc': 'The synapse tag used to annotate nodes included in this ATT&CK group ID.',
+                        'ex': 'cno.mitre.g0100',
+                    }),
+                    ('references', ('array', {'type': 'inet:url', 'uniq': True}), {
+                        'doc': 'An array of URLs that document the ATT&CK group.',
+                    }),
+                    ('techniques', ('array', {'type': 'it:mitre:attack:technique',
+                                              'uniq': True, 'sorted': True, 'split': ','}), {
+                        'doc': 'An array of ATT&CK technique IDs used by the group.',
+                    }),
+                    ('software', ('array', {'type': 'it:mitre:attack:software',
+                                            'uniq': True, 'sorted': True, 'split': ','}), {
+                        'doc': 'An array of ATT&CK software IDs used by the group.',
+                    }),
+                )),
+                ('it:mitre:attack:tactic', {}, (
+                    ('name', ('str', {'strip': True}), {
+                        'doc': 'The primary name for the ATT&CK tactic.',
+                    }),
+                    ('desc', ('str', {}), {
+                        'doc': 'A description of the ATT&CK tactic.',
+                        'disp': {'hint': 'text'},
+                    }),
+                    ('url', ('inet:url', {}), {
+                        'doc': 'The URL that documents the ATT&CK tactic.',
+                    }),
+                    ('tag', ('syn:tag', {}), {
+                        'doc': 'The synapse tag used to annotate nodes included in this ATT&CK tactic.',
+                        'ex': 'cno.mitre.ta0100',
+                    }),
+                    ('references', ('array', {'type': 'inet:url', 'uniq': True}), {
+                        'doc': 'An array of URLs that document the ATT&CK tactic.',
+                    }),
+                )),
+                ('it:mitre:attack:technique', {}, (
+                    ('name', ('str', {'strip': True}), {
+                        'doc': 'The primary name for the ATT&CK technique.',
+                    }),
+                    ('desc', ('str', {'strip': True}), {
+                        'doc': 'A description of the ATT&CK technique.',
+                        'disp': {'hint': 'text'},
+                    }),
+                    ('url', ('inet:url', {}), {
+                        'doc': 'The URL that documents the ATT&CK technique.',
+                    }),
+                    ('tag', ('syn:tag', {}), {
+                        'doc': 'The synapse tag used to annotate nodes included in this ATT&CK technique.',
+                        'ex': 'cno.mitre.t0100',
+                    }),
+                    ('references', ('array', {'type': 'inet:url', 'uniq': True}), {
+                        'doc': 'An array of URLs that document the ATT&CK technique.',
+                    }),
+                    ('parent', ('it:mitre:attack:technique', {}), {
+                        'doc': 'The parent ATT&CK technique on this sub-technique.',
+                    }),
+                    ('tactics', ('array', {'type': 'it:mitre:attack:tactic',
+                                           'uniq': True, 'sorted': True, 'split': ','}), {
+                        'doc': 'An array of ATT&CK tactics that include this technique.',
+                    }),
+                )),
+                ('it:mitre:attack:software', {}, (
+                    ('software', ('it:prod:soft', {}), {
+                        'doc': 'Used to map an ATT&CK software to a synapse it:prod:soft.',
+                    }),
+                    ('name', ('str', {'strip': True}), {
+                        'doc': 'The primary name for the ATT&CK software.',
+                    }),
+                    ('desc', ('str', {'strip': True}), {
+                        'doc': 'A description of the ATT&CK software.',
+                        'disp': {'hint': 'text'},
+                    }),
+                    ('url', ('inet:url', {}), {
+                        'doc': 'The URL that documents the ATT&CK software.',
+                    }),
+                    ('tag', ('syn:tag', {}), {
+                        'doc': 'The synapse tag used to annotate nodes included in this ATT&CK software.',
+                        'ex': 'cno.mitre.s0100',
+                    }),
+                    ('references', ('array', {'type': 'inet:url', 'uniq': True}), {
+                        'doc': 'An array of URLs that document the ATT&CK software.',
+                    }),
+                    ('techniques', ('array', {'type': 'it:mitre:attack:technique',
+                                              'uniq': True, 'sorted': True, 'split': ','}), {
+                        'doc': 'An array of techniques used by the software.',
+                    }),
+                )),
+                ('it:mitre:attack:mitigation', {}, (
+                    # TODO map to an eventual risk:mitigation
+                    ('name', ('str', {'strip': True}), {
+                        'doc': 'The primary name for the ATT&CK mitigation.',
+                    }),
+                    ('desc', ('str', {'strip': True}), {
+                        'doc': 'A description of the ATT&CK mitigation.',
+                        'disp': {'hint': 'text'},
+                    }),
+                    ('url', ('inet:url', {}), {
+                        'doc': 'The URL that documents the ATT&CK mitigation.',
+                    }),
+                    ('tag', ('syn:tag', {}), {
+                        'doc': 'The synapse tag used to annotate nodes included in this ATT&CK mitigation.',
+                        'ex': 'cno.mitre.m0100',
+                    }),
+                    ('references', ('array', {'type': 'inet:url', 'uniq': True}), {
+                        'doc': 'An array of URLs that document the ATT&CK mitigation.',
+                    }),
+                    ('addresses', ('array', {'type': 'it:mitre:attack:technique',
+                                             'uniq': True, 'sorted': True, 'split': ','}), {
+                        'doc': 'An array of ATT&CK technique IDs addressed by the mitigation.',
+                    }),
                 )),
                 ('it:dev:int', {}, ()),
                 ('it:dev:pipe', {}, ()),
@@ -409,17 +857,27 @@ class ItModule(s_module.CoreModule):
                     ('desc:short', ('str', {'lower': True}), {
                         'doc': 'A short description of the software.',
                     }),
+                    ('cpe', ('it:sec:cpe', {}), {
+                        'doc': 'The NIST CPE 2.3 string specifying this software.',
+                    }),
+                    ('author', ('ps:contact', {}), {
+                        'doc': 'The contact information of the org or person who authored the software.',
+                    }),
                     ('author:org', ('ou:org', {}), {
+                        'deprecated': True,
                         'doc': 'Organization which authored the software.',
                     }),
                     ('author:acct', ('inet:web:acct', {}), {
+                        'deprecated': True,
                         'doc': 'Web account of the software author.',
                     }),
                     ('author:email', ('inet:email', {}), {
+                        'deprecated': True,
                         'doc': 'Email address of the sofware author.',
                     }),
 
                     ('author:person', ('ps:person', {}), {
+                        'deprecated': True,
                         'doc': 'Person who authored the software.',
                     }),
                     ('url', ('inet:url', {}), {
@@ -484,6 +942,9 @@ class ItModule(s_module.CoreModule):
                     ('software:name', ('str', {'lower': True, 'strip': True}), {
                         'doc': 'The name of the software at a particular version.',
                     }),
+                    ('cpe', ('it:sec:cpe', {}), {
+                        'doc': 'The NIST CPE 2.3 string specifying this software version',
+                    }),
                     ('vers', ('it:dev:str', {}), {
                         'doc': 'Version string associated with this version instance.',
                     }),
